@@ -1,4 +1,4 @@
-import unittest
+import numpy as np
 
 from pynwb.ophys import TwoPhotonSeries, RoiResponseSeries, DfOverF, Fluorescence, PlaneSegmentation, \
     ImageSegmentation, OpticalChannel, ImagingPlane, MotionCorrection, CorrectedImageStack
@@ -6,8 +6,7 @@ from pynwb.image import ImageSeries
 from pynwb.base import TimeSeries
 from pynwb.device import Device
 from pynwb.base import ProcessingModule
-
-import numpy as np
+from pynwb.testing import TestCase
 
 
 def CreatePlaneSegmentation():
@@ -21,9 +20,9 @@ def CreatePlaneSegmentation():
 
     oc = OpticalChannel('test_optical_channel', 'description', 500.)
     device = Device(name='device_name')
-    ip = ImagingPlane('test_imaging_plane', oc, 'description', device, 600.,
-                      300., 'indicator', 'location', (1, 2, 1, 2, 3), 4.0,
-                      'unit', 'reference_frame')
+    ip = ImagingPlane(name='test_imaging_plane', optical_channel=oc, description='description', device=device,
+                      excitation_lambda=600., imaging_rate=300., indicator='indicator', location='location',
+                      reference_frame='reference_frame')
 
     pS = PlaneSegmentation('description', ip, 'test_name', iSS)
     pS.add_roi(pixel_mask=pix_mask[0:3], image_mask=img_mask[0])
@@ -31,25 +30,29 @@ def CreatePlaneSegmentation():
     return pS
 
 
-class TwoPhotonSeriesConstructor(unittest.TestCase):
+class TwoPhotonSeriesConstructor(TestCase):
     def test_init(self):
         oc = OpticalChannel('test_name', 'description', 500.)
         self.assertEqual(oc.description, 'description')
         self.assertEqual(oc.emission_lambda, 500.)
 
         device = Device(name='device_name')
-        ip = ImagingPlane('test_imaging_plane', oc, 'description', device, 600.,
-                          300., 'indicator', 'location', (50, 100, 3), 4.0, 'unit', 'reference_frame')
+        ip = ImagingPlane('test_imaging_plane', oc, description='description', device=device, excitation_lambda=600.,
+                          imaging_rate=300., indicator='indicator', location='location',
+                          reference_frame='reference_frame',
+                          origin_coords=[10, 20], origin_coords_unit='oc_unit',
+                          grid_spacing=[1, 2, 3], grid_spacing_unit='gs_unit')
         self.assertEqual(ip.optical_channel[0], oc)
         self.assertEqual(ip.device, device)
         self.assertEqual(ip.excitation_lambda, 600.)
         self.assertEqual(ip.imaging_rate, 300.)
         self.assertEqual(ip.indicator, 'indicator')
         self.assertEqual(ip.location, 'location')
-        self.assertEqual(ip.manifold, (50, 100, 3))
-        self.assertEqual(ip.conversion, 4.0)
-        self.assertEqual(ip.unit, 'unit')
         self.assertEqual(ip.reference_frame, 'reference_frame')
+        self.assertEqual(ip.origin_coords, [10, 20])
+        self.assertEqual(ip.origin_coords_unit, 'oc_unit')
+        self.assertEqual(ip.grid_spacing, [1, 2, 3])
+        self.assertEqual(ip.grid_spacing_unit, 'gs_unit')
 
         tPS = TwoPhotonSeries('test_tPS', unit='unit', field_of_view=[2., 3.],
                               imaging_plane=ip, pmt_gain=1.0, scan_line_rate=2.0, external_file=['external_file'],
@@ -68,20 +71,58 @@ class TwoPhotonSeriesConstructor(unittest.TestCase):
     def test_args(self):
         oc = OpticalChannel('test_name', 'description', 500.)
         device = Device(name='device_name')
-        ip = ImagingPlane('test_imaging_plane', oc, 'description', device, 600.,
-                          300., 'indicator', 'location', (50, 100, 3), 4.0, 'unit', 'reference_frame')
+        ip = ImagingPlane('test_imaging_plane', oc, description='description', device=device, excitation_lambda=600.,
+                          imaging_rate=300., indicator='indicator', location='location',
+                          reference_frame='reference_frame')
         with self.assertRaises(ValueError):  # no data or external file
             TwoPhotonSeries('test_tPS', unit='unit', field_of_view=[2., 3.],
                             imaging_plane=ip, pmt_gain=1.0, scan_line_rate=2.0,
                             starting_frame=[1, 2, 3], format='tiff', timestamps=[1., 2.])
 
+    def test_manifold_deprecated(self):
+        oc = OpticalChannel('test_name', 'description', 500.)
+        self.assertEqual(oc.description, 'description')
+        self.assertEqual(oc.emission_lambda, 500.)
 
-class MotionCorrectionConstructor(unittest.TestCase):
+        device = Device(name='device_name')
+
+        msg = "The 'manifold' argument is deprecated in favor of 'origin_coords' and 'grid_spacing'."
+        with self.assertWarnsWith(DeprecationWarning, msg):
+            ImagingPlane('test_imaging_plane', oc, description='description', device=device, excitation_lambda=600.,
+                         imaging_rate=300., indicator='indicator', location='location',
+                         manifold=(1, 1, (2, 2, 2)))
+
+    def test_conversion_deprecated(self):
+        oc = OpticalChannel('test_name', 'description', 500.)
+        self.assertEqual(oc.description, 'description')
+        self.assertEqual(oc.emission_lambda, 500.)
+
+        device = Device(name='device_name')
+
+        msg = "The 'conversion' argument is deprecated in favor of 'origin_coords' and 'grid_spacing'."
+        with self.assertWarnsWith(DeprecationWarning, msg):
+            ImagingPlane('test_imaging_plane', oc, description='description', device=device, excitation_lambda=600.,
+                         imaging_rate=300., indicator='indicator', location='location',  conversion=2.0)
+
+    def test_unit_deprecated(self):
+        oc = OpticalChannel('test_name', 'description', 500.)
+        self.assertEqual(oc.description, 'description')
+        self.assertEqual(oc.emission_lambda, 500.)
+
+        device = Device(name='device_name')
+
+        msg = "The 'unit' argument is deprecated in favor of 'origin_coords_unit' and 'grid_spacing_unit'."
+        with self.assertWarnsWith(DeprecationWarning, msg):
+            ImagingPlane('test_imaging_plane', oc, description='description', device=device, excitation_lambda=600.,
+                         imaging_rate=300., indicator='indicator', location='location', conversion=1.0, unit='my_unit')
+
+
+class MotionCorrectionConstructor(TestCase):
     def test_init(self):
         MotionCorrection(list())
 
 
-class CorrectedImageStackConstructor(unittest.TestCase):
+class CorrectedImageStackConstructor(TestCase):
     def test_init(self):
         is1 = ImageSeries(name='is1', data=np.ones((2, 2, 2)), unit='unit',
                           external_file=['external_file'], starting_frame=[1, 2, 3], format='tiff', timestamps=[1., 2.])
@@ -96,7 +137,7 @@ class CorrectedImageStackConstructor(unittest.TestCase):
         self.assertEqual(cis.xy_translation, ts)
 
 
-class RoiResponseSeriesConstructor(unittest.TestCase):
+class RoiResponseSeriesConstructor(TestCase):
     def test_init(self):
         ip = CreatePlaneSegmentation()
 
@@ -108,7 +149,7 @@ class RoiResponseSeriesConstructor(unittest.TestCase):
         self.assertEqual(ts.rois, rt_region)
 
 
-class DfOverFConstructor(unittest.TestCase):
+class DfOverFConstructor(TestCase):
     def test_init(self):
         ip = CreatePlaneSegmentation()
 
@@ -120,7 +161,7 @@ class DfOverFConstructor(unittest.TestCase):
         self.assertEqual(dof.roi_response_series['test_ts'], rrs)
 
 
-class FluorescenceConstructor(unittest.TestCase):
+class FluorescenceConstructor(TestCase):
     def test_init(self):
         ip = CreatePlaneSegmentation()
 
@@ -133,7 +174,7 @@ class FluorescenceConstructor(unittest.TestCase):
         self.assertEqual(ff.roi_response_series['test_ts'], ts)
 
 
-class ImageSegmentationConstructor(unittest.TestCase):
+class ImageSegmentationConstructor(TestCase):
 
     def test_init(self):
         ps = CreatePlaneSegmentation()
@@ -144,7 +185,7 @@ class ImageSegmentationConstructor(unittest.TestCase):
         self.assertEqual(iS[ps.name], iS.plane_segmentations[ps.name])
 
 
-class PlaneSegmentationConstructor(unittest.TestCase):
+class PlaneSegmentationConstructor(TestCase):
 
     def getBoilerPlateObjects(self):
 
@@ -153,8 +194,9 @@ class PlaneSegmentationConstructor(unittest.TestCase):
 
         device = Device(name='device_name')
         oc = OpticalChannel('test_optical_channel', 'description', 500.)
-        ip = ImagingPlane('test_imaging_plane', oc, 'description', device, 600.,
-                          300., 'indicator', 'location', (1, 2, 1, 2, 3), 4.0, 'unit', 'reference_frame')
+        ip = ImagingPlane('test_imaging_plane', oc, description='description', device=device, excitation_lambda=600.,
+                          imaging_rate=300., indicator='indicator', location='location',
+                          reference_frame='reference_frame')
         return iSS, ip
 
     def create_basic_plane_segmentation(self):
@@ -268,7 +310,3 @@ class PlaneSegmentationConstructor(unittest.TestCase):
         self.assertEqual(pS.reference_images, (iSS,))
 
         self.assertEqual(pS['image_mask'].data, img_mask)
-
-
-if __name__ == '__main__':
-    unittest.main()
